summaryrefslogtreecommitdiffstats
path: root/svtools
diff options
context:
space:
mode:
authorStefan Knorr (astron) <heinzlesspam@gmail.com>2012-03-13 19:03:16 +0100
committerStefan Knorr (astron) <heinzlesspam@gmail.com>2012-03-14 12:16:29 +0100
commit0e5430ae15ea941e7c158fa2dde902a098d26504 (patch)
tree0b123d3f9cb96e2013c5e881d0012a0d40cf9bc9 /svtools
parentsvtools/source/brwbox: translate comments (diff)
downloadcore-0e5430ae15ea941e7c158fa2dde902a098d26504.tar.gz
core-0e5430ae15ea941e7c158fa2dde902a098d26504.zip
svtools/source/config: fix typos, translate
Diffstat (limited to 'svtools')
-rw-r--r--svtools/source/config/fontsubstconfig.cxx4
-rw-r--r--svtools/source/config/miscopt.cxx20
-rw-r--r--svtools/source/config/optionsdrawinglayer.cxx8
-rw-r--r--svtools/source/config/printoptions.cxx18
-rw-r--r--svtools/source/config/test/test.cxx2
5 files changed, 26 insertions, 26 deletions
diff --git a/svtools/source/config/fontsubstconfig.cxx b/svtools/source/config/fontsubstconfig.cxx
index 57ef12234eae..61eaa7bf3510 100644
--- a/svtools/source/config/fontsubstconfig.cxx
+++ b/svtools/source/config/fontsubstconfig.cxx
@@ -188,13 +188,13 @@ void SvtFontSubstConfig::Apply()
{
OutputDevice::BeginFontSubstitution();
- // Alte Substitution entfernen
+ // remove old substitions
sal_uInt16 nOldCount = OutputDevice::GetFontSubstituteCount();
while (nOldCount)
OutputDevice::RemoveFontSubstitute(--nOldCount);
- // Neue Substitution einlesen
+ // read new substitutions
sal_Int32 nCount = IsEnabled() ? SubstitutionCount() : 0;
for (sal_Int32 i = 0; i < nCount; i++)
diff --git a/svtools/source/config/optionsdrawinglayer.cxx b/svtools/source/config/optionsdrawinglayer.cxx
index 64901fb4efe8..f000a9209dcb 100644
--- a/svtools/source/config/optionsdrawinglayer.cxx
+++ b/svtools/source/config/optionsdrawinglayer.cxx
@@ -984,9 +984,9 @@ SvtOptionsDrawinglayer::SvtOptionsDrawinglayer()
{
// Global access, must be guarded (multithreading!).
MutexGuard aGuard( GetOwnStaticMutex() );
- // Increase ouer refcount ...
+ // Increase our refcount ...
++m_nRefCount;
- // ... and initialize ouer data container only if it not already!
+ // ... and initialize our data container only if it not already!
if( m_pDataContainer == NULL )
{
m_pDataContainer = new SvtOptionsDrawinglayer_Impl();
@@ -1000,10 +1000,10 @@ SvtOptionsDrawinglayer::~SvtOptionsDrawinglayer()
{
// Global access, must be guarded (multithreading!)
MutexGuard aGuard( GetOwnStaticMutex() );
- // Decrease ouer refcount.
+ // Decrease our refcount.
--m_nRefCount;
// If last instance was deleted ...
- // we must destroy ouer static data container!
+ // we must destroy our static data container!
if( m_nRefCount <= 0 )
{
delete m_pDataContainer;
diff --git a/svtools/source/config/printoptions.cxx b/svtools/source/config/printoptions.cxx
index 56bc0181055e..789c7e6a6a1a 100644
--- a/svtools/source/config/printoptions.cxx
+++ b/svtools/source/config/printoptions.cxx
@@ -550,7 +550,7 @@ Mutex& SvtBasePrintOptions::GetOwnStaticMutex()
// ... we must create a new one. Protect follow code with the global mutex -
// It must be - we create a static variable!
MutexGuard aGuard( Mutex::getGlobalMutex() );
- // We must check our pointer again - because it can be that another instance of ouer class will be fastr then these!
+ // We must check our pointer again - because it can be that another instance of our class will be fastr then these!
if( pMutex == NULL )
{
// Create the new mutex and set it for return on static variable.
@@ -781,9 +781,9 @@ SvtPrinterOptions::SvtPrinterOptions()
{
// Global access, must be guarded (multithreading!).
MutexGuard aGuard( GetOwnStaticMutex() );
- // Increase ouer refcount ...
+ // Increase our refcount ...
++m_nRefCount;
- // ... and initialize ouer data container only if it not already!
+ // ... and initialize our data container only if it not already!
if( m_pStaticDataContainer == NULL )
{
OUString aRootPath( ROOTNODE_START );
@@ -801,10 +801,10 @@ SvtPrinterOptions::~SvtPrinterOptions()
{
// Global access, must be guarded (multithreading!)
MutexGuard aGuard( GetOwnStaticMutex() );
- // Decrease ouer refcount.
+ // Decrease our refcount.
--m_nRefCount;
// If last instance was deleted ...
- // we must destroy ouer static data container!
+ // we must destroy our static data container!
if( m_nRefCount <= 0 )
{
delete m_pStaticDataContainer;
@@ -821,9 +821,9 @@ SvtPrintFileOptions::SvtPrintFileOptions()
{
// Global access, must be guarded (multithreading!).
MutexGuard aGuard( GetOwnStaticMutex() );
- // Increase ouer refcount ...
+ // Increase our refcount ...
++m_nRefCount;
- // ... and initialize ouer data container only if it not already!
+ // ... and initialize our data container only if it not already!
if( m_pStaticDataContainer == NULL )
{
OUString aRootPath( ROOTNODE_START );
@@ -842,10 +842,10 @@ SvtPrintFileOptions::~SvtPrintFileOptions()
{
// Global access, must be guarded (multithreading!)
MutexGuard aGuard( GetOwnStaticMutex() );
- // Decrease ouer refcount.
+ // Decrease our refcount.
--m_nRefCount;
// If last instance was deleted ...
- // we must destroy ouer static data container!
+ // we must destroy our static data container!
if( m_nRefCount <= 0 )
{
delete m_pStaticDataContainer;
diff --git a/svtools/source/config/test/test.cxx b/svtools/source/config/test/test.cxx
index 09d11c8a4e19..90bf30ce0d21 100644
--- a/svtools/source/config/test/test.cxx
+++ b/svtools/source/config/test/test.cxx
@@ -29,7 +29,7 @@
//_________________________________________________________________________________________________________________
// switches
-// use it to enable test szenarios
+// use it to enable test scenarios
//_________________________________________________________________________________________________________________
#define TEST_DYNAMICMENUOPTIONS
diff --git a/svtools/source/config/miscopt.cxx b/svtools/source/config/miscopt.cxx
index a2f26ffdf2ea..f43a7c8c0020 100644
--- a/svtools/source/config/miscopt.cxx
+++ b/svtools/source/config/miscopt.cxx
@@ -248,7 +248,7 @@ class SvtMiscOptions_Impl : public ConfigItem
private:
/*-****************************************************************************************************//**
- @short return list of key names of ouer configuration management which represent oue module tree
+ @short return list of key names of our configuration management which represent oue module tree
@descr These methods return a static const list of key names. We need it to get needed values from our
configuration management.
@@ -303,7 +303,7 @@ SvtMiscOptions_Impl::SvtMiscOptions_Impl()
// Follow assignment use order of values in relation to our list of key names!
DBG_ASSERT( !(seqNames.getLength()!=seqValues.getLength()), "SvtMiscOptions_Impl::SvtMiscOptions_Impl()\nI miss some values of configuration keys!\n" );
// Copy values from list in right order to ouer internal member.
sal_Int32 nPropertyCount = seqValues.getLength();
for( sal_Int32 nProperty=0; nProperty<nPropertyCount; ++nProperty )
{
@@ -415,8 +415,8 @@ SvtMiscOptions_Impl::SvtMiscOptions_Impl()
}
}
// Enable notification mechanism of ouer baseclass.
// We need it to get information about changes outside these class on ouer used configuration keys!
EnableNotification( seqNames );
}
@@ -425,7 +425,7 @@ SvtMiscOptions_Impl::SvtMiscOptions_Impl()
//*****************************************************************************************************************
SvtMiscOptions_Impl::~SvtMiscOptions_Impl()
{
- // We must save our current values .. if user forget it!
+ // We must save our current values .. if user forgets it!
if( IsModified() == sal_True )
{
Commit();
@@ -453,7 +453,7 @@ void SvtMiscOptions_Impl::Load( const Sequence< OUString >& rPropertyNames )
// Follow assignment use order of values in relation to our list of key names!
DBG_ASSERT( !(rPropertyNames.getLength()!=seqValues.getLength()), "SvtSecurityOptions_Impl::SvtSecurityOptions_Impl()\nI miss some values of configuration keys!\n" );
// Copy values from list in right order to ouer internal member.
sal_Int32 nPropertyCount = seqValues.getLength();
for( sal_Int32 nProperty=0; nProperty<nPropertyCount; ++nProperty )
{
@@ -751,9 +751,9 @@ SvtMiscOptions::SvtMiscOptions()
{
// Global access, must be guarded (multithreading!).
MutexGuard aGuard( GetInitMutex() );
- // Increase ouer refcount ...
+ // Increase our refcount ...
++m_nRefCount;
- // ... and initialize ouer data container only if it not already exist!
+ // ... and initialize our data container only if it not already exist!
if( m_pDataContainer == NULL )
{
RTL_LOGFILE_CONTEXT(aLog, "svtools ( ??? ) ::SvtMiscOptions_Impl::ctor()");
@@ -769,10 +769,10 @@ SvtMiscOptions::~SvtMiscOptions()
{
// Global access, must be guarded (multithreading!)
MutexGuard aGuard( GetInitMutex() );
- // Decrease ouer refcount.
+ // Decrease our refcount.
--m_nRefCount;
// If last instance was deleted ...
// we must destroy ouer static data container!
if( m_nRefCount <= 0 )
{
delete m_pDataContainer;
@@ -303,7 +303,7 @@ SvtMiscOptions_Impl::SvtMiscOptions_Impl()
// Follow assignment use order of values in relation to our list of key names!
DBG_ASSERT( !(seqNames.getLength()!=seqValues.getLength()), "SvtMiscOptions_Impl::SvtMiscOptions_Impl()\nI miss some values of configuration keys!\n" );
- // Copy values from list in right order to ouer internal member.
+ // Copy values from list in right order to our internal member.
sal_Int32 nPropertyCount = seqValues.getLength();
for( sal_Int32 nProperty=0; nProperty<nPropertyCount; ++nProperty )
@@ -415,8 +415,8 @@ SvtMiscOptions_Impl::SvtMiscOptions_Impl()
}
}
- // Enable notification mechanism of ouer baseclass.
- // We need it to get information about changes outside these class on ouer used configuration keys!
+ // Enable notification mechanism of our baseclass.
+ // We need it to get information about changes outside these class on our used configuration keys!
EnableNotification( seqNames );
}
@@ -453,7 +453,7 @@ void SvtMiscOptions_Impl::Load( const Sequence< OUString >& rPropertyNames )
// Follow assignment use order of values in relation to our list of key names!
DBG_ASSERT( !(rPropertyNames.getLength()!=seqValues.getLength()), "SvtSecurityOptions_Impl::SvtSecurityOptions_Impl()\nI miss some values of configuration keys!\n" );
- // Copy values from list in right order to ouer internal member.
+ // Copy values from list in right order to our internal member.
sal_Int32 nPropertyCount = seqValues.getLength();
for( sal_Int32 nProperty=0; nProperty<nPropertyCount; ++nProperty )
@@ -769,10 +769,10 @@ SvtMiscOptions::~SvtMiscOptions()
// If last instance was deleted ...
- // we must destroy ouer static data container!
+ // we must destroy our static data container!
if( m_nRefCount <= 0 )
{